@@ -18,6 +18,7 @@ import logging
 import shutil
 import socket
 import warnings
+from contextlib import nullcontext
 
 import h5py
 import matplotlib.pyplot as plt
@@ -196,7 +197,7 @@ def flag(
             )
             sb_freq = f"{beam_label}/{sb_label}/astronomy_data/frequency"
             data = h5[sb_data]
-            freq = np.array(h5[sb_freq])
+            freq = np.squeeze(h5[sb_freq]) # Ensure 1D
             flag = np.array(h5[sb_flag])
 
             f_per = np.sum(flag) / np.sum(np.ones_like(flag)) * 100
@@ -273,9 +274,11 @@ def main(
     # Initialise dask
     with LocalCluster(
         n_workers=cores, threads_per_worker=threads_per_worker
-    ) as cluster, Client(cluster) as client, performance_report(filename=report):
+    ) as cluster, Client(cluster) as client, performance_report(
+        filename=report
+    ) if report else nullcontext():
         logger.info(f"Dask running at {client.dashboard_link}")
-        if report is not None:
+        if report:
             logger.info(f"Writting report to {report}")
 
         todos = {}
